@@ -36,5 +36,7 @@ G_DECLARE_FINAL_TYPE (ChattyApplication, chatty_application, CHATTY, APPLICATION
 
 ChattyApplication *chatty_application_new (void);
 ChattyChat        *chatty_application_get_active_chat (ChattyApplication *self);
+void               chatty_application_set_active_chat (ChattyApplication *self,
+                                                       ChattyChat        *chat);
 
 G_END_DECLS
