@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <gtk/gtk.h>
+#include <adwaita.h>
 
 #include "chatty-item.h"
 
@@ -16,7 +16,7 @@ G_BEGIN_DECLS
 
 #define CHATTY_TYPE_AVATAR (chatty_avatar_get_type ())
 
-G_DECLARE_FINAL_TYPE (ChattyAvatar, chatty_avatar, CHATTY, AVATAR, GtkBin)
+G_DECLARE_FINAL_TYPE (ChattyAvatar, chatty_avatar, CHATTY, AVATAR, AdwBin)
 
 void       chatty_avatar_set_title (ChattyAvatar *item,
                                     const char   *title);
