@@ -11,7 +11,6 @@
 #pragma once
 
 #include <gtk/gtk.h>
-#include <handy.h>
 
 G_BEGIN_DECLS
 
@@ -19,9 +18,9 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (ChattyFpRow, chatty_fp_row, CHATTY, FP_ROW, GtkListBoxRow)
 
-GtkWidget *chatty_fp_row_new      (HdyValueObject *item);
-void       chatty_fp_row_set_item (ChattyFpRow    *self,
-                                   HdyValueObject *item);
+GtkWidget *chatty_fp_row_new      (GtkStringObject *item);
+void       chatty_fp_row_set_item (ChattyFpRow     *self,
+                                   GtkStringObject *item);
 
 
 G_END_DECLS
