@@ -10,6 +10,7 @@
 # include "config.h"
 #endif
 
+#include <glib/gi18n.h>
 #include <glib.h>
 #ifdef PURPLE_ENABLED
 # include <purple.h>
@@ -154,7 +155,7 @@ chatty_utils_strip_utm_from_url (const char *url_to_parse)
     return g_strdup (url_to_parse);
 
   url = g_uri_parse (url_to_parse, G_URI_FLAGS_NONE, NULL);
-  if (!url)
+  if (!url || !g_uri_get_query (url))
     return g_strdup (url_to_parse);
 
   tracking_ids = load_tracking_ids ();
@@ -246,6 +247,143 @@ chatty_utils_strip_utm_from_message (const char *message)
   return g_string_free (str, FALSE);
 }
 
+char *
+chatty_utils_vcard_get_contact_title (GFile* vcard)
+{
+  char *contact_title = NULL;
+  g_autofree char *contents = NULL;
+  g_autoptr(GError) error = NULL;
+  g_auto(GStrv) lines = NULL;
+  gsize length;
+
+  g_file_load_contents (vcard,
+                        NULL,
+                        &contents,
+                        &length,
+                        NULL,
+                        &error);
+
+  if (error) {
+    g_warning ("error opening file: %s", error->message);
+    return NULL;
+  }
+
+  lines = g_strsplit_set (contents, "\r\n", -1);
+  for (int i = 0; lines[i] != NULL; i++) {
+     if (g_str_has_prefix (lines[i], "FN:")) {
+       g_clear_pointer (&contact_title, g_free);
+
+       contact_title = g_strdup (lines[i] + 3);
+
+       /*
+        * Formatted name ("FN:") is better formatted and required in later versions
+        * of vCals vs. Name ("N:"). Since we found it, we can be done searching.
+        */
+       break;
+     }
+     if (g_str_has_prefix (lines[i], "N:")) {
+       g_auto(GStrv) tokens = NULL;
+       unsigned int token_length = 0;
+
+       if (g_strcmp0 (lines[i], "N:;;;;") == 0)
+         continue;
+
+       g_clear_pointer (&contact_title, g_free);
+
+       tokens = g_strsplit_set (lines[i] + 2, ";", 5);
+       token_length = g_strv_length (tokens);
+       /* https://www.rfc-editor.org/rfc/rfc2426#section-3.1.2  This should be a length of 5, but let's not risk it*/
+       /* Translators: Order is: Family Name, Given Name, Additional/Middle Names, Honorific Prefixes, and Honorific Suffixes */
+       if (token_length == 5) {
+         if (*tokens[3])
+           contact_title = g_strdup_printf (_("%s %s %s %s"), tokens[3], tokens[1], tokens[0], tokens[4]);
+         else
+           contact_title = g_strdup_printf (_("%s %s %s"), tokens[1], tokens[0], tokens[4]);
+
+       } else if (token_length == 4) {
+         if (*tokens[3])
+           contact_title = g_strdup_printf (_("%s %s %s"), tokens[3], tokens[1], tokens[0]);
+         else
+           contact_title = g_strdup_printf (_("%s %s"), tokens[1], tokens[0]);
+
+       } else if (token_length == 3 || token_length == 2)
+         contact_title = g_strdup_printf (_("%s %s"), tokens[1], tokens[0]);
+       else
+         contact_title = g_strdup (tokens[0]);
+
+       /*
+        * Formatted name ("FN:") is better formatted and required in later versions
+        * of vCals vs. Name ("N:"). So if we find Name ("N:"), let's keep
+        * searching for formatted name.
+        */
+       continue;
+     }
+     if (g_str_has_prefix (lines[i], "ORG:")) {
+       g_auto(GStrv) tokens = NULL;
+
+       /* Only process this if we cannot find FN or N */
+       if (contact_title != NULL)
+         continue;
+
+       if (g_strcmp0 (lines[i], "ORG:;") == 0)
+         continue;
+
+       if (g_strcmp0 (lines[i], "ORG:") == 0)
+         continue;
+
+       tokens = g_strsplit_set (lines[i] + 4, ";", 2);
+
+       contact_title = g_strdup (tokens[0]);
+       continue;
+     }
+  }
+
+ if (contact_title)
+   g_strstrip (contact_title);
+
+ return contact_title;
+}
+
+char *
+chatty_utils_vcal_get_event_title (GFile* vcal)
+{
+  char *event_title = NULL;
+  g_autofree char *contents = NULL;
+  g_autoptr(GError) error = NULL;
+  g_auto(GStrv) lines = NULL;
+  gsize length;
+
+  g_file_load_contents (vcal,
+                        NULL,
+                        &contents,
+                        &length,
+                        NULL,
+                        &error);
+
+  if (error) {
+    g_warning ("error opening file: %s", error->message);
+    return NULL;
+  }
+
+  lines = g_strsplit_set (contents, "\r\n", -1);
+  for (int i = 0; lines[i] != NULL; i++) {
+     if (g_str_has_prefix (lines[i], "SUMMARY")) {
+       g_auto(GStrv) tokens = NULL;
+       unsigned int token_length = 0;
+
+       tokens = g_strsplit_set (lines[i] + 2, ":", 2);
+       token_length = g_strv_length (tokens);
+       /* https://www.rfc-editor.org/rfc/rfc5545#section-3.8.1.12  This should be a length of 2, but let's not risk it*/
+       if (token_length == 2)
+         event_title = g_strdup (tokens[1]);
+
+       break;
+     }
+  }
+
+  return event_title;
+}
+
 /*
  * matrix_id_is_valid:
  * @name: A string
@@ -493,11 +631,11 @@ chatty_utils_window_has_toplevel_focus (GtkWindow *window)
   return !!(state & GDK_TOPLEVEL_STATE_FOCUSED);
 }
 
-const char *
+char *
 chatty_utils_get_purple_dir (void)
 {
 #ifdef PURPLE_ENABLED
-  return purple_user_dir ();
+  return g_strdup (purple_user_dir ());
 #endif
   return g_build_filename (g_get_home_dir (), ".purple", NULL);
 }
@@ -728,6 +866,7 @@ utils_create_thumbnail (GTask        *task,
 
 void
 chatty_utils_create_thumbnail_async (GFile               *file,
+                                     GCancellable        *cancellable,
                                      GAsyncReadyCallback  callback,
                                      gpointer             user_data)
 {
@@ -736,7 +875,7 @@ chatty_utils_create_thumbnail_async (GFile               *file,
   g_return_if_fail (G_IS_FILE (file));
   g_return_if_fail (callback);
 
-  task = g_task_new (NULL, NULL, callback, user_data);
+  task = g_task_new (NULL, cancellable, callback, user_data);
   g_task_set_task_data (task, g_object_ref (file), g_object_unref);
 
   g_task_run_in_thread (task, utils_create_thumbnail);
