@@ -24,13 +24,10 @@
 #include "chatty-log.h"
 
 /**
- * SECTION: chatty-chat
- * @title: ChattyChat
- * @short_description: An abstraction over #PurpleConversation
- * @include: "chatty-chat.h"
- *
- * libpurple doesn’t have a nice OOP interface for managing anything.
- * This class hides all the complexities surrounding it.
+ * SECTION: chatty-ma-chat
+ * @title: ChattyMaChat
+ * @short_description: An abstraction over libcmatrix
+ * @include: "chatty-ma-chat.h"
  */
 
 struct _ChattyMaChat
@@ -116,18 +113,27 @@ ma_chat_get_past_events_cb (GObject      *object,
                             gpointer      user_data)
 {
   g_autoptr(ChattyMaChat) self = user_data;
-  /* g_autoptr(GPtrArray) events = NULL; */
   g_autoptr(GError) error = NULL;
+  CmRoom *room = CM_ROOM (object);
 
   g_assert (CHATTY_IS_MA_CHAT (self));
 
-  cm_room_load_past_events_finish (CM_ROOM (object), result, &error);
+  cm_room_load_past_events_finish (room, result, &error);
 
   self->history_is_loading = FALSE;
   g_object_notify (G_OBJECT (self), "loading-history");
 
-  if (error)
-    g_warning ("Error: %s", error->message);
+  if (error) {
+    g_autoptr(GString) str = NULL;
+
+    str = g_string_new (NULL);
+    g_string_append (str, "Error getting past events in room");
+    chatty_log_anonymize_value (str, cm_room_get_id (room));
+    g_string_append_printf (str, ": %s", error->message);
+
+    g_warning ("%s", str->str);
+
+  }
 }
 
 static gboolean
@@ -268,6 +274,7 @@ chatty_ma_chat_set_encryption_async (ChattyChat          *chat,
   g_assert (self->cm_client);
 
   task = g_task_new (self, NULL, callback, user_data);
+  g_task_set_source_tag (task, chatty_ma_chat_set_encryption_async);
 
   if (!enable) {
     g_task_return_new_error (task,
@@ -283,6 +290,18 @@ chatty_ma_chat_set_encryption_async (ChattyChat          *chat,
                                    g_steal_pointer (&task));
 }
 
+static gboolean
+chatty_ma_chat_set_encryption_finish (ChattyChat   *self,
+                                      GAsyncResult *result,
+                                      GError       **error)
+{
+  g_assert (CHATTY_IS_CHAT (self));
+  g_assert (G_IS_TASK (result));
+  g_assert (g_task_get_source_tag (G_TASK (result)) == chatty_ma_chat_set_encryption_async);
+
+  return g_task_propagate_boolean (G_TASK (result), error);
+}
+
 static void
 ma_chat_accept_invite_cb (GObject      *object,
                           GAsyncResult *result,
@@ -313,11 +332,25 @@ chatty_ma_chat_accept_invite_async (ChattyChat          *chat,
   g_assert (CHATTY_IS_MA_CHAT (chat));
 
   task = g_task_new (self, NULL, callback, user_data);
+  g_task_set_source_tag (task, chatty_ma_chat_accept_invite_async);
+
   cm_room_accept_invite_async (self->cm_room, NULL,
                                ma_chat_accept_invite_cb,
                                task);
 }
 
+static gboolean
+chatty_ma_chat_accept_invite_finish (ChattyChat   *self,
+                                     GAsyncResult *result,
+                                     GError       **error)
+{
+  g_assert (CHATTY_IS_CHAT (self));
+  g_assert (G_IS_TASK (result));
+  g_assert (g_task_get_source_tag (G_TASK (result)) == chatty_ma_chat_accept_invite_async);
+
+  return g_task_propagate_boolean (G_TASK (result), error);
+}
+
 static void
 ma_chat_reject_invite_cb (GObject      *object,
                           GAsyncResult *result,
@@ -348,11 +381,25 @@ chatty_ma_chat_reject_invite_async (ChattyChat          *chat,
   g_assert (CHATTY_IS_MA_CHAT (chat));
 
   task = g_task_new (self, NULL, callback, user_data);
+  g_task_set_source_tag (task, chatty_ma_chat_reject_invite_async);
+
   cm_room_reject_invite_async (self->cm_room, NULL,
                                ma_chat_reject_invite_cb,
                                task);
 }
 
+static gboolean
+chatty_ma_chat_reject_invite_finish (ChattyChat   *self,
+                                     GAsyncResult *result,
+                                     GError       **error)
+{
+  g_assert (CHATTY_IS_CHAT (self));
+  g_assert (G_IS_TASK (result));
+  g_assert (g_task_get_source_tag (G_TASK (result)) == chatty_ma_chat_reject_invite_async);
+
+  return g_task_propagate_boolean (G_TASK (result), error);
+}
+
 static const char *
 chatty_ma_chat_get_last_message (ChattyChat *chat)
 {
@@ -436,6 +483,7 @@ ma_chat_send_message_cb (GObject      *object,
   g_autofree char *event_id = NULL;
   ChattyMessage *message;
   g_autoptr(GError) err = NULL;
+  gboolean is_file;
 
   g_assert (G_IS_TASK (task));
 
@@ -444,7 +492,12 @@ ma_chat_send_message_cb (GObject      *object,
   g_assert (CHATTY_IS_MA_CHAT (self));
   g_assert (CHATTY_IS_MESSAGE (message));
 
-  event_id = cm_room_send_text_finish (self->cm_room, result, &err);
+  is_file = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (task), "is-file"));
+
+  if (is_file)
+    event_id = cm_room_send_file_finish (self->cm_room, result, &err);
+  else
+    event_id = cm_room_send_text_finish (self->cm_room, result, &err);
 
   /* We add only failed to send messages.  If sending succeeded,
    * we shall get the same via the /sync responses */
@@ -465,11 +518,11 @@ chatty_ma_chat_send_message_async (ChattyChat          *chat,
                                    GAsyncReadyCallback  callback,
                                    gpointer             user_data)
 {
-  ChattyMaChat *self = (ChattyMaChat *)chat;
+  ChattyMaChat *self = CHATTY_MA_CHAT (chat);
+  g_autoptr (GTask) task = NULL;
   const char *event_id;
   GList *files = NULL;
   GFile *file = NULL;
-  GTask *task;
 
   g_assert (CHATTY_IS_MA_CHAT (self));
   g_assert (CHATTY_IS_MESSAGE (message));
@@ -477,26 +530,41 @@ chatty_ma_chat_send_message_async (ChattyChat          *chat,
   chatty_message_set_status (message, CHATTY_STATUS_SENDING, 0);
 
   task = g_task_new (self, NULL, callback, user_data);
+  g_task_set_source_tag (task, chatty_ma_chat_send_message_async);
   g_task_set_task_data (task, g_object_ref (message), g_object_unref);
   g_list_store_append (self->message_list, message);
 
   files = chatty_message_get_files (message);
 
   if (files && files->data && chatty_file_get_path (files->data))
-    file = g_file_new_for_path (files->data);
+    file = g_file_new_for_path (chatty_file_get_path (files->data));
 
-  if (file)
+  if (file) {
+    g_object_set_data (G_OBJECT (task), "is-file", GINT_TO_POINTER (TRUE));
     event_id = cm_room_send_file_async (self->cm_room, file, NULL,
                                         NULL, NULL, NULL,
-                                        ma_chat_send_message_cb, task);
-  else
+                                        ma_chat_send_message_cb, g_steal_pointer (&task));
+  } else {
     event_id = cm_room_send_text_async (self->cm_room,
                                         chatty_message_get_text (message),
                                         NULL,
-                                        ma_chat_send_message_cb, task);
+                                        ma_chat_send_message_cb, g_steal_pointer (&task));
+  }
   g_object_set_data_full (G_OBJECT (message), "event-id", g_strdup (event_id), g_free);
 }
 
+static gboolean
+chatty_ma_chat_send_message_finish (ChattyChat    *self,
+                                    GAsyncResult  *result,
+                                    GError       **error)
+{
+  g_assert (CHATTY_IS_CHAT (self));
+  g_assert (G_IS_TASK (result));
+  g_assert (g_task_get_source_tag (G_TASK (result)) == chatty_ma_chat_send_message_async);
+
+  return g_task_propagate_boolean (G_TASK (result), error);
+}
+
 static void
 ma_chat_download_cb (GObject      *object,
                      GAsyncResult *result,
@@ -528,6 +596,7 @@ chatty_ma_chat_get_files_async (ChattyChat          *chat,
   g_assert (CHATTY_IS_MESSAGE (message));
 
   task = g_task_new (self, NULL, callback, user_data);
+  g_task_set_source_tag (task, chatty_ma_chat_get_files_async);
   g_object_set_data_full (G_OBJECT (task), "message", g_object_ref (message), g_object_unref);
 
   files = chatty_message_get_files (message);
@@ -551,6 +620,18 @@ chatty_ma_chat_get_files_async (ChattyChat          *chat,
                                 g_steal_pointer (&task));
 }
 
+static gboolean
+chatty_ma_chat_get_files_finish (ChattyChat    *self,
+                                 GAsyncResult  *result,
+                                 GError       **error)
+{
+  g_assert (CHATTY_IS_CHAT (self));
+  g_assert (G_IS_TASK (result));
+  g_assert (g_task_get_source_tag (G_TASK (result)) == chatty_ma_chat_get_files_async);
+
+  return g_task_propagate_boolean (G_TASK (result), error);
+}
+
 static gboolean
 chatty_ma_chat_get_buddy_typing (ChattyChat *chat)
 {
@@ -637,6 +718,16 @@ chatty_ma_chat_get_protocols (ChattyItem *item)
   return CHATTY_PROTOCOL_MATRIX;
 }
 
+static GListModel *
+chatty_ma_chat_get_users (ChattyChat *chat)
+{
+  ChattyMaChat *self = (ChattyMaChat *)chat;
+
+  g_assert (CHATTY_IS_MA_CHAT (self));
+
+  return G_LIST_MODEL (self->buddy_list);
+}
+
 static void
 ma_chat_get_avatar_cb (GObject      *object,
                        GAsyncResult *result,
@@ -654,8 +745,13 @@ ma_chat_get_avatar_cb (GObject      *object,
   if (error || !stream)
     return;
 
-  self->avatar = gdk_pixbuf_new_from_stream_at_scale (stream, 192, -1, TRUE, NULL, NULL);
-  g_signal_emit_by_name (self, "avatar-changed", 0);
+  self->avatar = gdk_pixbuf_new_from_stream_at_scale (stream, 192, -1, TRUE, NULL, &error);
+  if (self->avatar)
+    g_signal_emit_by_name (self, "avatar-changed", 0);
+  else
+    CHATTY_WARNING (chatty_ma_chat_get_chat_name (CHATTY_CHAT (self)),
+                    "Could not get avatar '%s' for matrix chat:",
+                    error->message);
 }
 
 static GdkPixbuf *
@@ -716,15 +812,21 @@ chatty_ma_chat_class_init (ChattyMaChatClass *klass)
   chat_class->is_loading_history = chatty_ma_chat_is_loading_history;
   chat_class->get_messages = chatty_ma_chat_get_messages;
   chat_class->get_account  = chatty_ma_chat_get_account;
+  chat_class->get_users = chatty_ma_chat_get_users;
   chat_class->get_encryption = chatty_ma_chat_get_encryption;
   chat_class->set_encryption_async = chatty_ma_chat_set_encryption_async;
+  chat_class->set_encryption_finish = chatty_ma_chat_set_encryption_finish;
   chat_class->accept_invite_async = chatty_ma_chat_accept_invite_async;
+  chat_class->accept_invite_finish = chatty_ma_chat_accept_invite_finish;
   chat_class->reject_invite_async = chatty_ma_chat_reject_invite_async;
+  chat_class->reject_invite_finish = chatty_ma_chat_reject_invite_finish;
   chat_class->get_last_message = chatty_ma_chat_get_last_message;
   chat_class->get_unread_count = chatty_ma_chat_get_unread_count;
   chat_class->set_unread_count = chatty_ma_chat_set_unread_count;
   chat_class->send_message_async = chatty_ma_chat_send_message_async;
+  chat_class->send_message_finish = chatty_ma_chat_send_message_finish;
   chat_class->get_files_async = chatty_ma_chat_get_files_async;
+  chat_class->get_files_finish = chatty_ma_chat_get_files_finish;
   chat_class->get_buddy_typing = chatty_ma_chat_get_buddy_typing;
   chat_class->set_typing = chatty_ma_chat_set_typing;
 }
@@ -762,6 +864,16 @@ ma_chat_encryption_changed_cb (ChattyMaChat *self)
   g_object_notify (G_OBJECT (self), "encrypt");
 }
 
+
+static void
+ma_unread_count_changed_cb (ChattyMaChat *self)
+{
+  g_assert (CHATTY_IS_MA_CHAT (self));
+
+  g_signal_emit_by_name (self, "changed", 0);
+}
+
+
 static void
 joined_members_changed_cb (ChattyMaChat *self,
                            guint         position,
@@ -857,6 +969,9 @@ chatty_ma_chat_new_with_room (CmRoom *room)
   g_signal_connect_object (room, "notify::encrypted",
                            G_CALLBACK (ma_chat_encryption_changed_cb),
                            self, G_CONNECT_SWAPPED);
+  g_signal_connect_object (room, "notify::unread-count",
+                           G_CALLBACK (ma_unread_count_changed_cb),
+                           self, G_CONNECT_SWAPPED);
 
   members = cm_room_get_joined_members (room);
   g_signal_connect_object (members, "items-changed",
@@ -928,3 +1043,11 @@ chatty_ma_chat_matches_id (ChattyMaChat *self,
 
   return g_strcmp0 (self->room_id, room_id) == 0;
 }
+
+const char *
+chatty_ma_chat_get_topic (ChattyMaChat  *self)
+{
+  g_return_val_if_fail (CHATTY_IS_MA_CHAT (self), NULL);
+
+  return cm_room_get_topic (self->cm_room);
+}
