@@ -32,11 +32,13 @@ gboolean    chatty_mmsd_get_settings          (ChattyMmsd      *self,
                                                const char     **apn,
                                                const char     **mmsc,
                                                const char     **proxy,
+                                               const char     **phone_number,
                                                gboolean        *use_smil);
 void        chatty_mmsd_set_settings_async    (ChattyMmsd      *self,
                                                const char      *apn,
                                                const char      *mmsc,
                                                const char      *proxy,
+                                               const char      *phone_number,
                                                gboolean         use_smil,
                                                GCancellable    *cancellable,
                                                GAsyncReadyCallback callback,
