@@ -7,7 +7,6 @@
 
 #include <glib/gi18n.h>
 
-#include "gtk3-to-4.h"
 #include "chatty-purple-request.h"
 #include "chatty-manager.h"
 
@@ -24,15 +23,22 @@ cb_action_response (GtkDialog         *dialog,
   purple_request_close (PURPLE_REQUEST_INPUT, data);
 }
 
-
 static void
-cb_file_exists (GtkWidget         *widget,
-                gint               response,
-                ChattyRequestData *data)
+cb_file_exists_save (GObject         *dialog,
+                     GAsyncResult    *response,
+                     gpointer        user_data)
 {
+  ChattyRequestData *data = user_data;
+  g_autoptr(GError) error = NULL;
   g_autoptr(GFile) file = NULL;
 
-  if (response != GTK_RESPONSE_ACCEPT) {
+  file = gtk_file_dialog_save_finish (GTK_FILE_DIALOG (dialog), response, &error);
+  g_clear_object (&dialog);
+
+  if (!file) {
+    if (!g_error_matches (error, GTK_DIALOG_ERROR, GTK_DIALOG_ERROR_DISMISSED))
+      g_warning ("Error getting file: %s", error->message);
+
     if (data->cbs[0] != NULL) {
       ((PurpleRequestFileCb)data->cbs[0])(data->user_data, NULL);
     }
@@ -42,7 +48,39 @@ cb_file_exists (GtkWidget         *widget,
     return;
   }
 
-  file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (data->dialog));
+  data->file_name = g_file_get_path (file);
+
+  if (data->cbs[1] != NULL) {
+    ((PurpleRequestFileCb)data->cbs[1])(data->user_data, data->file_name);
+  }
+
+  purple_request_close (data->type, data);
+}
+
+static void
+cb_file_exists_open (GObject         *dialog,
+                     GAsyncResult    *response,
+                     gpointer        user_data)
+{
+  ChattyRequestData *data = user_data;
+  g_autoptr(GFile) file = NULL;
+  g_autoptr(GError) error = NULL;
+
+  file = gtk_file_dialog_open_finish (GTK_FILE_DIALOG (dialog), response, &error);
+  g_clear_object (&dialog);
+
+  if (!file) {
+    if (!g_error_matches (error, GTK_DIALOG_ERROR, GTK_DIALOG_ERROR_DISMISSED))
+      g_warning ("Error getting file: %s", error->message);
+
+    if (data->cbs[0] != NULL) {
+      ((PurpleRequestFileCb)data->cbs[0])(data->user_data, NULL);
+    }
+
+    purple_request_close (data->type, data);
+
+    return;
+  }
 
   data->file_name = g_file_get_path (file);
 
@@ -77,7 +115,11 @@ chatty_request_action (const char         *title,
     // for certificates
     return NULL;
   }
-
+/*
+ * TODO: Fix this depreciation
+ * https://gitlab.gnome.org/World/Chatty/-/issues/842
+ */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   data            = g_new0 (ChattyRequestData, 1);
   data->type      = PURPLE_REQUEST_ACTION;
   data->user_data = user_data;
@@ -117,12 +159,11 @@ chatty_request_action (const char         *title,
   g_free (buttons);
 
   gtk_dialog_set_default_response (GTK_DIALOG(dialog), action_count - 1 - default_action);
-
-  window = gtk_application_get_active_window (GTK_APPLICATION (g_application_get_default ()));
   gtk_window_set_transient_for (GTK_WINDOW(dialog), window);
 
   data->dialog = dialog;
 
+G_GNUC_END_IGNORE_DEPRECATIONS
   return data;
 }
 
@@ -158,7 +199,7 @@ chatty_request_file (const char         *title,
 {
   ChattyRequestData *data;
   GtkWindow         *window;
-  GtkWidget         *dialog;
+  GtkFileDialog *dialog;
 
   data = g_new0 (ChattyRequestData, 1);
   data->type = PURPLE_REQUEST_FILE;
@@ -171,42 +212,35 @@ chatty_request_file (const char         *title,
 
   window = gtk_application_get_active_window (GTK_APPLICATION (g_application_get_default ()));
 
-  dialog = gtk_file_chooser_dialog_new (title ? title : (save_dialog ? _("Save File...") :
-                                          _("Open File...")),
-                                        window,
-                                        save_dialog ? GTK_FILE_CHOOSER_ACTION_SAVE :
-                                          GTK_FILE_CHOOSER_ACTION_OPEN,
-                                        _("Cancel"),
-                                        GTK_RESPONSE_CANCEL,
-                                        save_dialog ? _("Save") : _("Open"),
-                                        GTK_RESPONSE_ACCEPT,
-                                        NULL);
+  dialog = gtk_file_dialog_new ();
 
-  gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
+  if (save_dialog)
+    gtk_file_dialog_set_title (dialog, _("Save File…"));
+  else
+    gtk_file_dialog_set_title (dialog, _("Open File…"));
 
   if ((filename != NULL) && (*filename != '\0')) {
     if (save_dialog) {
-      gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER(dialog), filename);
+       g_autoptr(GFile) file = NULL;
+
+       file = g_file_new_for_path (filename);
+       gtk_file_dialog_set_initial_file (dialog, file);
     } else if (g_file_test(filename, G_FILE_TEST_EXISTS)) {
       g_autoptr(GFile) file = NULL;
-
       file = g_file_new_for_path (filename);
-
-      gtk_file_chooser_set_file (GTK_FILE_CHOOSER (dialog), file, NULL);
+      gtk_file_dialog_set_initial_file (dialog, file);
     }
   }
 
-  g_signal_connect (G_OBJECT(GTK_FILE_CHOOSER(dialog)),
-                    "response",
-                    G_CALLBACK(cb_file_exists),
-                    data);
-
   window = gtk_application_get_active_window (GTK_APPLICATION (g_application_get_default ()));
   gtk_window_set_transient_for (GTK_WINDOW(dialog), window);
 
-  data->dialog = dialog;
+  data->dialog = GTK_WIDGET (dialog);
 
-  gtk_widget_set_visible (dialog, TRUE);
+  if (save_dialog)
+    gtk_file_dialog_save (dialog, window, NULL, cb_file_exists_save, data);
+  else
+    gtk_file_dialog_open (dialog, window, NULL, cb_file_exists_open, data);
 
   return (void *)data;
 }
