@@ -38,7 +38,6 @@ struct _ChattyItemClass
   ChattyItemState  (*get_state)           (ChattyItem           *self);
   void             (*set_state)           (ChattyItem           *self,
                                            ChattyItemState       state);
-  ChattyFileInfo  *(*get_avatar_file)     (ChattyItem           *self);
   GdkPixbuf       *(*get_avatar)          (ChattyItem           *self);
   void             (*get_avatar_async)    (ChattyItem           *self,
                                            GCancellable         *cancellable,
@@ -73,7 +72,6 @@ void             chatty_item_set_username        (ChattyItem           *self,
 ChattyItemState  chatty_item_get_state           (ChattyItem           *self);
 void             chatty_item_set_state           (ChattyItem           *self,
                                                   ChattyItemState       state);
-ChattyFileInfo  *chatty_item_get_avatar_file     (ChattyItem           *self);
 GdkPixbuf       *chatty_item_get_avatar          (ChattyItem           *self);
 void             chatty_item_get_avatar_async    (ChattyItem           *self,
                                                   GCancellable         *cancellable,
