@@ -240,7 +240,6 @@ queue_data (CmNet      *self,
   g_autoptr(SoupMessage) message = NULL;
   g_autoptr(GUri) uri = NULL;
   GUri *old_uri;
-  g_autoptr(GBytes) content_data = NULL;
   GCancellable *cancellable;
   SoupMessagePriority msg_priority;
   int priority = 0;
@@ -254,29 +253,25 @@ queue_data (CmNet      *self,
             method == SOUP_METHOD_POST ||
             method == SOUP_METHOD_PUT);
 
-  uri = g_uri_parse (self->homeserver, SOUP_HTTP_URI_FLAGS, NULL);
-  old_uri = uri;
+  old_uri = g_uri_parse (self->homeserver, SOUP_HTTP_URI_FLAGS, NULL);
   uri = soup_uri_copy (old_uri, SOUP_URI_PATH, uri_path, SOUP_URI_NONE);
   g_clear_pointer (&old_uri, g_uri_unref);
 
-  if (self->access_token) {
-    if (!query)
-      query = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+  if (query) {
+    g_autofree char *query_hash = NULL;
 
-    g_hash_table_replace (query, g_strdup ("access_token"), g_strdup (self->access_token));
-    {
-      g_autofree char *query_hash = NULL;
-
-      old_uri = uri;
-      query_hash = soup_form_encode_hash (query);
-      uri = soup_uri_copy (old_uri, SOUP_URI_QUERY, query_hash, SOUP_URI_NONE);
-      g_clear_pointer (&old_uri, g_uri_unref);
-    }
-    g_hash_table_unref (query);
+    old_uri = uri;
+    query_hash = soup_form_encode_hash (query);
+    uri = soup_uri_copy (old_uri, SOUP_URI_QUERY, query_hash, SOUP_URI_NONE);
+    g_clear_pointer (&old_uri, g_uri_unref);
   }
 
   message = soup_message_new_from_uri (method, uri);
   soup_message_headers_append (soup_message_get_request_headers (message), "Accept-Encoding", "gzip");
+  if (self->access_token) {
+    g_autofree char *header = g_strdup_printf ("Bearer %s", self->access_token);
+    soup_message_headers_append (soup_message_get_request_headers (message), "Authorization", header);
+  }
 
   priority = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (task), "priority"));
 
@@ -294,8 +289,9 @@ queue_data (CmNet      *self,
   soup_message_set_priority (message, msg_priority);
 
   if (data) {
-      content_data = g_bytes_new_take (data, size);
-      soup_message_set_request_body_from_bytes (message, "application/json", content_data);
+    g_autoptr(GBytes) content_data = g_bytes_new_take (data, size);
+
+    soup_message_set_request_body_from_bytes (message, "application/json", content_data);
   }
 
   cancellable = g_task_get_cancellable (task);
@@ -515,6 +511,7 @@ void
 cm_net_get_file_async (CmNet                 *self,
                        const char            *uri,
                        CmEncFileInfo         *enc_file,
+                       const char * const    *versions,
                        GCancellable          *cancellable,
                        GAsyncReadyCallback    callback,
                        gpointer               user_data)
@@ -522,6 +519,7 @@ cm_net_get_file_async (CmNet                 *self,
   g_autofree char *url = NULL;
   SoupMessage *msg;
   GTask *task;
+  gboolean needs_auth = FALSE;
 
   g_return_if_fail (CM_IS_NET (self));
   g_return_if_fail (uri && *uri);
@@ -533,8 +531,16 @@ cm_net_get_file_async (CmNet                 *self,
     const char *file_url;
 
     file_url = uri + strlen ("mxc://");
-    url = g_strconcat (self->homeserver,
-                       "/_matrix/media/r0/download/", file_url, NULL);
+    if (versions && g_strv_contains (versions, "v1.11")) {
+      /* Endpoints for authenticated media
+       * https://matrix.org/blog/2024/06/20/matrix-v1.11-release/ */
+      url = g_strconcat (self->homeserver,
+                         "/_matrix/client/v1/media/download/", file_url, NULL);
+      needs_auth = TRUE;
+    } else {
+      url = g_strconcat (self->homeserver,
+                         "/_matrix/media/r0/download/", file_url, NULL);
+    }
   }
 
   if (!url)
@@ -547,6 +553,13 @@ cm_net_get_file_async (CmNet                 *self,
   g_object_set_data (G_OBJECT (task), "file", enc_file);
   g_object_set_data_full (G_OBJECT (task), "msg", msg, g_object_unref);
 
+  if (needs_auth && self->access_token) {
+    SoupMessageHeaders *headers = soup_message_get_request_headers (msg);
+    g_autofree char *auth = g_strdup_printf ("Bearer %s", self->access_token);
+
+    soup_message_headers_replace (headers, "Authorization", auth);
+  }
+
   soup_session_send_async (self->file_session, msg, 0, cancellable,
                            net_get_file_stream_cb, task);
 }
