@@ -9,9 +9,7 @@
 
 #define G_LOG_DOMAIN "cm-verification-event"
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include "cm-config.h"
 
 #include "cm-client-private.h"
 #include "cm-olm-sas-private.h"
