@@ -10,9 +10,7 @@
 
 #define G_LOG_DOMAIN "cm-room-member"
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include "cm-config.h"
 
 #include "cm-client.h"
 #include "cm-client-private.h"
